@@ -6,7 +6,7 @@
 #' `dmap_at()` and `dmap_if()` recycle length 1 vectors to
 #' the group sizes.
 #' @inheritParams purrr::map
-#' @inheritParams purrr::as_function
+#' @inheritParams rlang::as_function
 #' @inheritParams purrr::map_if
 #' @param .d A data frame.
 #' @export
@@ -30,7 +30,7 @@ dmap <- function(.d, .f, ...) {
     sliced_dmap(.d, .f, ...)
   } else {
     res <- .Call(map_impl, environment(), ".d", ".f", "list")
-    dplyr::as_data_frame(res)
+    dplyr::as_tibble(res)
   }
 }
 
